==> percona-server-mongodb_4.0.9.orig.tar.gz: percona-server-mongodb-4.0.9-4/src/mongo/db/storage/test_harness_helper.cpp <==

/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/db/storage/test_harness_helper.h"

#include <exception>
#include <stdexcept>

#include "mongo/util/assert_util.h"

namespace mongo {
namespace {
stdx::function<std::unique_ptr<HarnessHelper>()> basicHarnessFactory;
}  // namespace


HarnessHelper::HarnessHelper() {
    setGlobalServiceContext(ServiceContext::make());
    Client::initThread(getThreadName());
}

HarnessHelper::~HarnessHelper() {
    Client::destroy();
    setGlobalServiceContext({});
}

void registerHarnessHelperFactory(stdx::function<std::unique_ptr<HarnessHelper>()> factory) {
    basicHarnessFactory = std::move(factory);
}

auto newHarnessHelper() -> std::unique_ptr<HarnessHelper> {
    return basicHarnessFactory();
}

}  // namespace mongo

==> percona-server-mongodb-36_3.6.6.orig.tar.gz: percona-server-mongodb-3.6.6-1.4/src/mongo/db/storage/test_harness_helper.cpp <==
/**
 *    Copyright (C) 2016 MongoDB Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/db/storage/test_harness_helper.h"

#include <exception>
#include <stdexcept>

#include "mongo/util/assert_util.h"

namespace mongo {
namespace {
stdx::function<std::unique_ptr<HarnessHelper>()> basicHarnessFactory;
}  // namespace
}  // namespace mongo


mongo::HarnessHelper::~HarnessHelper() = default;

void mongo::registerHarnessHelperFactory(stdx::function<std::unique_ptr<HarnessHelper>()> factory) {
    basicHarnessFactory = std::move(factory);
}

auto mongo::newHarnessHelper() -> std::unique_ptr<HarnessHelper> {
    return basicHarnessFactory();
}
